// Fichier MainActivity.java
/**
 * Activité principale de l'application 2048.
 * Gère l'interface utilisateur (plateau, scores, boutons), coordonne les interactions
 * avec la logique du jeu (classe Game) et la gestion des statistiques (classe GameStats).
 * Gère également le cycle de vie de l'application et la persistance de l'état du jeu.
 */
package legion.muyue.best2048;

import android.annotation.SuppressLint;
import android.app.AlertDialog;
import android.content.ActivityNotFoundException;
import android.provider.Settings;
import com.google.android.material.switchmaterial.SwitchMaterial;
import android.content.Intent;
import android.content.SharedPreferences;
import android.net.Uri;
import android.os.Bundle;
import android.util.TypedValue;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewStub;
import android.view.animation.AnimationUtils;
import android.widget.TextView;

import androidx.activity.EdgeToEdge;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.content.ContextCompat;
import androidx.gridlayout.widget.GridLayout;
import android.widget.Button;
import android.widget.Toast;


public class MainActivity extends AppCompatActivity {

    // --- UI Elements ---
    private GridLayout boardGridLayout;
    private TextView currentScoreTextView;
    private TextView highestScoreTextView;
    private Button newGameButton;
    private Button multiplayerButton;
    private Button statisticsButton;
    private Button menuButton;
    private ViewStub statisticsViewStub;
    private View inflatedStatsView;

    // --- Game Logic & Stats ---
    private Game game;
    private GameStats gameStats;
    private static final int BOARD_SIZE = 4;

    // --- State Management ---
    private boolean statisticsVisible = false;
    private enum GameFlowState { PLAYING, WON_DIALOG_SHOWN, GAME_OVER }
    private GameFlowState currentGameState = GameFlowState.PLAYING;

    // --- Preferences ---
    private SharedPreferences preferences;
    private static final String PREFS_NAME = "Best2048_Prefs";
    private static final String HIGH_SCORE_KEY = "high_score";
    private static final String GAME_STATE_KEY = "game_state";

    // --- Activity Lifecycle ---

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        EdgeToEdge.enable(this);
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        findViews();
        initializeGameAndStats();
        setupListeners();
    }

    @Override
    protected void onResume() {
        super.onResume();
        // Redémarre le timer seulement si le jeu est en cours (pas gagné/perdu)
        if (game != null && gameStats != null && currentGameState == GameFlowState.PLAYING) {
            gameStats.setCurrentGameStartTimeMs(System.currentTimeMillis());
        }
        // Gère le réaffichage potentiel des stats si l'activité reprend
        if (statisticsVisible) {
            if (inflatedStatsView != null) { // Si déjà gonflé
                updateStatisticsTextViews(); // Met à jour les données affichées
                inflatedStatsView.setVisibility(View.VISIBLE);
                multiplayerButton.setVisibility(View.GONE);
            } else {
                // Si pas encore gonflé (cas rare mais possible), on le fait afficher
                toggleStatistics();
            }
        }
    }

    @Override
    protected void onPause() {
        super.onPause();
        // Sauvegarde l'état et les stats si le jeu existe
        if (game != null && gameStats != null) {
            // Met à jour le temps total SI la partie était en cours
            if (currentGameState == GameFlowState.PLAYING) {
                gameStats.addPlayTime(System.currentTimeMillis() - gameStats.getCurrentGameStartTimeMs()); // Utilise méthode GameStats
            }
            saveGame();       // Sauvegarde l'état du jeu (plateau + score courant) et le HS
            gameStats.saveStats(); // Sauvegarde toutes les stats via GameStats
        }
    }

    // --- Initialisation ---

    /**
     * Récupère les références des vues du layout principal via leur ID.
     */
    private void findViews() {
        boardGridLayout = findViewById(R.id.gameBoard);
        currentScoreTextView = findViewById(R.id.scoreLabel);
        highestScoreTextView = findViewById(R.id.highScoreLabel);
        newGameButton = findViewById(R.id.restartButton);
        statisticsButton = findViewById(R.id.statsButton);
        menuButton = findViewById(R.id.menuButton);
        multiplayerButton = findViewById(R.id.multiplayerButton);
        statisticsViewStub = findViewById(R.id.statsViewStub);
    }

    /**
     * Initialise les objets Game et GameStats.
     * Charge l'état du jeu sauvegardé (s'il existe) et le meilleur score.
     * Met à jour l'interface utilisateur initiale.
     */
    private void initializeGameAndStats() {
        preferences = getSharedPreferences(PREFS_NAME, MODE_PRIVATE);
        gameStats = new GameStats(this);
        loadGame(); // Charge jeu et met à jour high score
        updateUI();
        if (game == null) {
            // Si loadGame échoue ou aucune sauvegarde, startNewGame gère l'initialisation
            startNewGame();
        }
        // L'état (currentGameState) est défini dans loadGame ou startNewGame
    }

    /**
     * Configure les listeners pour les boutons et le plateau de jeu (swipes).
     * Mise à jour pour le bouton Menu.
     */
    private void setupListeners() {
        newGameButton.setOnClickListener(v -> {
            v.startAnimation(AnimationUtils.loadAnimation(this, R.anim.button_press));
            showRestartConfirmationDialog();
        });
        statisticsButton.setOnClickListener(v -> {
            v.startAnimation(AnimationUtils.loadAnimation(this, R.anim.button_press));
            toggleStatistics();
        });
        // Modifié pour appeler la nouvelle méthode showMenu()
        menuButton.setOnClickListener(v -> {
            v.startAnimation(AnimationUtils.loadAnimation(this, R.anim.button_press));
            showMenu(); // Appelle la méthode du menu
        });
        multiplayerButton.setOnClickListener(v -> {
            v.startAnimation(AnimationUtils.loadAnimation(this, R.anim.button_press));
            showMultiplayerScreen(); // Affiche dialogue placeholder
        });
        setupSwipeListener();
    }

    // --- Mise à jour UI ---

    /**
     * Met à jour complètement l'interface utilisateur (plateau et scores).
     */
    private void updateUI() {
        if (game == null) return;
        updateBoard();
        updateScores();
    }

    /**
     * Redessine le plateau de jeu en créant/mettant à jour les TextViews des tuiles.
     */
    private void updateBoard() {
        boardGridLayout.removeAllViews();
        for (int row = 0; row < BOARD_SIZE; row++) {
            for (int col = 0; col < BOARD_SIZE; col++) {
                TextView tileTextView = new TextView(this);
                int value = game.getCellValue(row, col);
                setTileStyle(tileTextView, value);
                // Définit les LayoutParams pour que la tuile remplisse la cellule du GridLayout
                GridLayout.LayoutParams params = new GridLayout.LayoutParams();
                params.width = 0; params.height = 0; // Poids gère la taille
                params.rowSpec = GridLayout.spec(row, 1f); // Prend 1 fraction de l'espace en hauteur
                params.columnSpec = GridLayout.spec(col, 1f); // Prend 1 fraction de l'espace en largeur
                int margin = (int) getResources().getDimension(R.dimen.tile_margin);
                params.setMargins(margin, margin, margin, margin);
                tileTextView.setLayoutParams(params);
                boardGridLayout.addView(tileTextView);
            }
        }
    }

    /**
     * Met à jour les TextViews affichant le score courant et le meilleur score.
     */
    private void updateScores() {
        currentScoreTextView.setText(getString(R.string.score_placeholder, game.getCurrentScore()));
        highestScoreTextView.setText(getString(R.string.high_score_placeholder, game.getHighestScore()));
    }

    /**
     * Applique le style visuel (fond, texte, taille) à une TextView représentant une tuile.
     * @param tileTextView La TextView de la tuile.
     * @param value La valeur numérique de la tuile (0 pour vide).
     */
    private void setTileStyle(TextView tileTextView, int value) {
        tileTextView.setText(value > 0 ? String.valueOf(value) : "");
        tileTextView.setGravity(Gravity.CENTER);
        tileTextView.setTypeface(null, android.graphics.Typeface.BOLD);
        int backgroundColorId; int textColorId; int textSizeId;
        switch (value) {
            case 0:    backgroundColorId = R.color.tile_empty; textColorId = android.R.color.transparent; textSizeId = R.dimen.text_size_tile_small; break;
            case 2:    backgroundColorId = R.color.tile_2;     textColorId = R.color.text_tile_low;     textSizeId = R.dimen.text_size_tile_small; break;
            case 4:    backgroundColorId = R.color.tile_4;     textColorId = R.color.text_tile_low;     textSizeId = R.dimen.text_size_tile_small; break;
            case 8:    backgroundColorId = R.color.tile_8;     textColorId = R.color.text_tile_high;    textSizeId = R.dimen.text_size_tile_small; break;
            case 16:   backgroundColorId = R.color.tile_16;    textColorId = R.color.text_tile_high;    textSizeId = R.dimen.text_size_tile_small; break;
            case 32:   backgroundColorId = R.color.tile_32;    textColorId = R.color.text_tile_high;    textSizeId = R.dimen.text_size_tile_small; break;
            case 64:   backgroundColorId = R.color.tile_64;    textColorId = R.color.text_tile_high;    textSizeId = R.dimen.text_size_tile_small; break;
            case 128:  backgroundColorId = R.color.tile_128;   textColorId = R.color.text_tile_high;    textSizeId = R.dimen.text_size_tile_medium; break;
            case 256:  backgroundColorId = R.color.tile_256;   textColorId = R.color.text_tile_high;    textSizeId = R.dimen.text_size_tile_medium; break;
            case 512:  backgroundColorId = R.color.tile_512;   textColorId = R.color.text_tile_high;    textSizeId = R.dimen.text_size_tile_medium; break;
            case 1024: backgroundColorId = R.color.tile_1024;  textColorId = R.color.text_tile_high;    textSizeId = R.dimen.text_size_tile_large; break;
            case 2048: backgroundColorId = R.color.tile_2048;  textColorId = R.color.text_tile_high;    textSizeId = R.dimen.text_size_tile_large; break;
            default:   backgroundColorId = R.color.tile_super;   textColorId = R.color.text_tile_high;    textSizeId = R.dimen.text_size_tile_large; break;
        }
        tileTextView.setBackgroundResource(R.drawable.tile_background);
        tileTextView.getBackground().setTint(ContextCompat.getColor(this, backgroundColorId));
        tileTextView.setTextColor(ContextCompat.getColor(this, textColorId));
        tileTextView.setTextSize(TypedValue.COMPLEX_UNIT_PX, getResources().getDimension(textSizeId));
    }


    // --- Gestion des Actions Utilisateur ---

    /**
     * Configure le listener pour détecter les swipes sur le plateau de jeu.
     */
    @SuppressLint("ClickableViewAccessibility")
    private void setupSwipeListener() {
        boardGridLayout.setOnTouchListener(new OnSwipeTouchListener(this, new OnSwipeTouchListener.SwipeListener() {
            @Override public void onSwipeTop() { handleSwipe(Direction.UP); }
            @Override public void onSwipeBottom() { handleSwipe(Direction.DOWN); }
            @Override public void onSwipeLeft() { handleSwipe(Direction.LEFT); }
            @Override public void onSwipeRight() { handleSwipe(Direction.RIGHT); }
        }));
    }

    /**
     * Traite un geste de swipe de l'utilisateur sur le plateau de jeu.
     * Met à jour le jeu, les statistiques et l'UI, et vérifie les conditions de fin de partie.
     * @param direction La direction du swipe détecté.
     */
    private void handleSwipe(Direction direction) {
        if (game == null || gameStats == null || currentGameState == GameFlowState.GAME_OVER) {
            return; // Ignore swipe si jeu terminé ou non initialisé
        }

        int scoreBefore = game.getCurrentScore();
        boolean boardChanged = false;

        // Tente d'effectuer le mouvement dans l'objet Game
        switch (direction) {
            case UP:    boardChanged = game.pushUp(); break;
            case DOWN:  boardChanged = game.pushDown(); break;
            case LEFT:  boardChanged = game.pushLeft(); break;
            case RIGHT: boardChanged = game.pushRight(); break;
        }

        // Si le mouvement a modifié le plateau
        if (boardChanged) {
            gameStats.recordMove();
            int scoreAfter = game.getCurrentScore();
            int scoreDelta = scoreAfter - scoreBefore;
            if (scoreDelta > 0) {
                gameStats.recordMerge(1); // Simplification: compte comme 1 fusion si score augmente
                if (scoreAfter > game.getHighestScore()) {
                    game.setHighestScore(scoreAfter);
                    gameStats.setHighestScore(scoreAfter); // Met à jour aussi dans GameStats pour sauvegarde
                }
            }
            gameStats.updateHighestTile(game.getHighestTileValue());
            game.addNewTile(); // Ajoute une nouvelle tuile
            updateUI(); // Rafraîchit l'affichage
        }

        // Vérifie l'état final après le mouvement (même si boardChanged est false)
        if (currentGameState != GameFlowState.GAME_OVER) {
            if (game.isGameWon() && currentGameState == GameFlowState.PLAYING) {
                currentGameState = GameFlowState.WON_DIALOG_SHOWN;
                long timeTaken = System.currentTimeMillis() - gameStats.getCurrentGameStartTimeMs();
                gameStats.recordWin(timeTaken);
                showGameWonKeepPlayingDialog();
            } else if (game.isGameOver()) {
                currentGameState = GameFlowState.GAME_OVER;
                long timeTaken = System.currentTimeMillis() - gameStats.getCurrentGameStartTimeMs();
                gameStats.recordLoss();
                gameStats.endGame(timeTaken); // Finalise temps, etc.
                showGameOverDialog();
                // Met à jour l'UI pour afficher le score final si Game Over atteint sans mouvement (rare)
                if (!boardChanged) updateUI();
            }
        }
    }

    /** Énumération pour les directions de swipe. */
    private enum Direction { UP, DOWN, LEFT, RIGHT }

    // --- Dialogues ---

    /**
     * Affiche la boîte de dialogue demandant confirmation avant de redémarrer.
     */
    private void showRestartConfirmationDialog() {
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        LayoutInflater inflater = getLayoutInflater();
        View dialogView = inflater.inflate(R.layout.dialog_restart_confirm, null);
        builder.setView(dialogView);
        Button cancelButton = dialogView.findViewById(R.id.dialogCancelButton);
        Button confirmButton = dialogView.findViewById(R.id.dialogConfirmButton);
        final AlertDialog dialog = builder.create();
        cancelButton.setOnClickListener(v -> dialog.dismiss());
        confirmButton.setOnClickListener(v -> { dialog.dismiss(); startNewGame(); });
        dialog.show();
    }

    /**
     * Démarre une nouvelle partie logiquement et rafraîchit l'UI.
     * Réinitialise les stats de la partie en cours via `gameStats.startGame()`.
     * Ferme le panneau de statistiques s'il est ouvert.
     */
    private void startNewGame() {
        if (gameStats == null) gameStats = new GameStats(this); // Précaution si initialisation a échoué avant
        gameStats.startGame(); // Réinitialise stats de partie (temps, mouvements, etc.)
        game = new Game(); // Crée un nouveau jeu logique
        game.setHighestScore(gameStats.getOverallHighScore()); // Applique le meilleur score global au nouveau jeu
        currentGameState = GameFlowState.PLAYING; // Définit l'état à JOUER

        // Ferme le panneau de statistiques s'il était ouvert
        if (statisticsVisible) {
            toggleStatistics(); // Utilise la méthode existante pour masquer proprement
        }
        // Assure que le bouton multijoueur est visible (pourrait être masqué par les stats)
        multiplayerButton.setVisibility(View.VISIBLE);

        updateUI(); // Met à jour l'affichage (plateau, scores)
    }


    /**
     * Affiche la boîte de dialogue quand 2048 est atteint, en utilisant un layout personnalisé.
     * Propose de continuer à jouer ou de commencer une nouvelle partie.
     */
    private void showGameWonKeepPlayingDialog() {
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        LayoutInflater inflater = getLayoutInflater();
        View dialogView = inflater.inflate(R.layout.dialog_game_won, null);
        builder.setView(dialogView);
        builder.setCancelable(false);

        Button keepPlayingButton = dialogView.findViewById(R.id.dialogKeepPlayingButton);
        Button newGameButton = dialogView.findViewById(R.id.dialogNewGameButtonWon);
        final AlertDialog dialog = builder.create();

        keepPlayingButton.setOnClickListener(v -> {
            // L'état est déjà WON_DIALOG_SHOWN, on ne fait rien de spécial, le jeu continue.
            dialog.dismiss();
        });
        newGameButton.setOnClickListener(v -> {
            dialog.dismiss();
            startNewGame();
        });
        dialog.show();
    }

    /**
     * Affiche la boîte de dialogue de fin de partie (plus de mouvements), en utilisant un layout personnalisé.
     * Propose Nouvelle Partie ou Quitter.
     */
    private void showGameOverDialog() {
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        LayoutInflater inflater = getLayoutInflater();
        View dialogView = inflater.inflate(R.layout.dialog_game_over, null);
        builder.setView(dialogView);
        builder.setCancelable(false);

        TextView messageTextView = dialogView.findViewById(R.id.dialogMessageGameOver);
        Button newGameButton = dialogView.findViewById(R.id.dialogNewGameButtonGameOver);
        Button quitButton = dialogView.findViewById(R.id.dialogQuitButtonGameOver);
        messageTextView.setText(getString(R.string.game_over_message, game.getCurrentScore()));
        final AlertDialog dialog = builder.create();

        newGameButton.setOnClickListener(v -> {
            dialog.dismiss();
            startNewGame();
        });
        quitButton.setOnClickListener(v -> {
            dialog.dismiss();
            finish(); // Ferme l'application
        });
        dialog.show();
    }

    // --- Menu Principal ---

    /**
     * Affiche la boîte de dialogue du menu principal en utilisant un layout personnalisé.
     * Attache les listeners aux boutons pour déclencher les actions correspondantes.
     */
    private void showMenu() {
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        LayoutInflater inflater = getLayoutInflater();
        View dialogView = inflater.inflate(R.layout.dialog_main_menu, null); // Gonfle le layout personnalisé
        builder.setView(dialogView);
        builder.setCancelable(true);

        // Récupère les boutons du layout personnalisé
        Button howToPlayButton = dialogView.findViewById(R.id.menuButtonHowToPlay);
        Button settingsButton = dialogView.findViewById(R.id.menuButtonSettings);
        Button aboutButton = dialogView.findViewById(R.id.menuButtonAbout);
        Button returnButton = dialogView.findViewById(R.id.menuButtonReturn);

        final AlertDialog dialog = builder.create();

        // Attache les listeners aux boutons
        howToPlayButton.setOnClickListener(v -> {
            dialog.dismiss(); // Ferme le menu
            showHowToPlayDialog(); // Ouvre la dialogue "Comment Jouer"
        });

        settingsButton.setOnClickListener(v -> {
            dialog.dismiss(); // Ferme le menu
            showSettingsDialog(); // Ouvre la dialogue placeholder "Paramètres"
        });

        aboutButton.setOnClickListener(v -> {
            dialog.dismiss(); // Ferme le menu
            showAboutDialog(); // Ouvre la dialogue "À Propos"
        });

        returnButton.setOnClickListener(v -> {
            dialog.dismiss(); // Ferme simplement le menu
        });

        dialog.show(); // Affiche la boîte de dialogue
    }

    /**
     * Affiche une boîte de dialogue expliquant les règles du jeu,
     * en utilisant un layout personnalisé pour une meilleure présentation.
     */
    private void showHowToPlayDialog() {
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        LayoutInflater inflater = getLayoutInflater();
        View dialogView = inflater.inflate(R.layout.dialog_how_to_play, null); // Gonfle le layout
        builder.setView(dialogView);
        builder.setCancelable(true); // Permet de fermer en cliquant à côté

        // Récupère le bouton OK DANS la vue gonflée
        Button okButton = dialogView.findViewById(R.id.dialogOkButtonHowToPlay);

        final AlertDialog dialog = builder.create();

        okButton.setOnClickListener(v -> dialog.dismiss()); // Ferme simplement

        dialog.show();
    }

    /**
     * Affiche la boîte de dialogue des paramètres en utilisant un layout personnalisé.
     * Gère les interactions avec les différentes options.
     */
    private void showSettingsDialog() {
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        LayoutInflater inflater = getLayoutInflater();
        View dialogView = inflater.inflate(R.layout.dialog_settings, null);
        builder.setView(dialogView);
        builder.setCancelable(true); // Permet de fermer en cliquant à côté

        // Récupération des vues
        SwitchMaterial switchSound = dialogView.findViewById(R.id.switchSound);
        SwitchMaterial switchNotifications = dialogView.findViewById(R.id.switchNotifications);
        Button permissionsButton = dialogView.findViewById(R.id.buttonManagePermissions);
        Button shareStatsButton = dialogView.findViewById(R.id.buttonShareStats);
        Button resetStatsButton = dialogView.findViewById(R.id.buttonResetStats);
        Button quitAppButton = dialogView.findViewById(R.id.buttonQuitApp);
        Button closeButton = dialogView.findViewById(R.id.buttonCloseSettings);

        final AlertDialog dialog = builder.create();

        // Configuration initiale des switches (désactivés pour l'instant)
        switchSound.setEnabled(false);
        switchSound.setChecked(false); // Mettre à jour avec la vraie valeur si implémenté
        switchSound.setOnCheckedChangeListener((buttonView, isChecked) -> {
            // TODO: Implémenter la logique Son ON/OFF
            Toast.makeText(this, "Gestion du son à venir.", Toast.LENGTH_SHORT).show();
            // switchSound.setChecked(!isChecked); // Revenir en arrière car pas implémenté
        });

        switchNotifications.setEnabled(false);
        switchNotifications.setChecked(false); // Mettre à jour avec la vraie valeur si implémenté
        switchNotifications.setOnCheckedChangeListener((buttonView, isChecked) -> {
            // TODO: Implémenter la logique Notifications ON/OFF
            Toast.makeText(this, "Gestion des notifications à venir.", Toast.LENGTH_SHORT).show();
            // switchNotifications.setChecked(!isChecked);
        });

        // Listener bouton Permissions
        permissionsButton.setOnClickListener(v -> {
            Intent intent = new Intent(Settings.ACTION_APPLICATION_DETAILS_SETTINGS);
            Uri uri = Uri.fromParts("package", getPackageName(), null);
            intent.setData(uri);
            try {
                startActivity(intent);
            } catch (ActivityNotFoundException e) {
                Toast.makeText(this, "Impossible d'ouvrir les paramètres de l'application.", Toast.LENGTH_LONG).show();
            }
            dialog.dismiss(); // Ferme les paramètres après clic
        });

        // Listener bouton Partager Stats
        shareStatsButton.setOnClickListener(v -> {
            shareStats();
            dialog.dismiss(); // Ferme après partage (ou tentative)
        });

        // Listener bouton Réinitialiser Stats
        resetStatsButton.setOnClickListener(v -> {
            dialog.dismiss(); // Ferme d'abord la dialogue des paramètres
            showResetStatsConfirmationDialog(); // Ouvre la confirmation
        });

        // Listener bouton Quitter
        quitAppButton.setOnClickListener(v -> {
            dialog.dismiss();
            finishAffinity(); // Ferme toutes les activités de l'application
        });

        // Listener bouton Fermer
        closeButton.setOnClickListener(v -> dialog.dismiss());

        dialog.show();
    }

    /**
     * Crée et lance une Intent pour partager les statistiques du joueur.
     */
    private void shareStats() {
        if (gameStats == null) return;

        // Construit le message à partager
        String shareBody = getString(R.string.share_stats_body,
                gameStats.getOverallHighScore(),
                gameStats.getHighestTile(),
                gameStats.getNumberOfTimesObjectiveReached(),
                gameStats.getTotalGamesStarted(), // Ou totalGamesPlayed ?
                GameStats.formatTime(gameStats.getTotalPlayTimeMs()),
                gameStats.getTotalMoves()
        );

        Intent shareIntent = new Intent(Intent.ACTION_SEND);
        shareIntent.setType("text/plain");
        shareIntent.putExtra(Intent.EXTRA_SUBJECT, getString(R.string.share_stats_subject));
        shareIntent.putExtra(Intent.EXTRA_TEXT, shareBody);

        try {
            startActivity(Intent.createChooser(shareIntent, getString(R.string.share_stats_title)));
        } catch (ActivityNotFoundException e) {
            Toast.makeText(this, "Aucune application de partage disponible.", Toast.LENGTH_SHORT).show();
        }
    }

    /**
     * Affiche une boîte de dialogue pour confirmer la réinitialisation des statistiques.
     */
    private void showResetStatsConfirmationDialog() {
        new AlertDialog.Builder(this)
                .setTitle(R.string.reset_stats_confirm_title)
                .setMessage(R.string.reset_stats_confirm_message)
                .setPositiveButton(R.string.confirm, (dialog, which) -> {
                    resetStatistics(); // Appelle la méthode de réinitialisation
                    dialog.dismiss();
                })
                .setNegativeButton(R.string.cancel, (dialog, which) -> dialog.dismiss())
                .setIcon(android.R.drawable.ic_dialog_alert) // Icône d'avertissement
                .show();
    }

    /**
     * Réinitialise toutes les statistiques via GameStats et sauvegarde les changements.
     * Affiche une confirmation à l'utilisateur.
     */
    private void resetStatistics() {
        if (gameStats != null) {
            gameStats.resetStats(); // Réinitialise les stats dans l'objet
            gameStats.saveStats();  // Sauvegarde les stats réinitialisées
            // Met aussi à jour le highScore de l'objet Game courant (si une partie est en cours)
            if(game != null){
                game.setHighestScore(gameStats.getOverallHighScore()); // Le HS est aussi reset dans GameStats
                updateScores(); // Rafraichit l'affichage du HS si visible
            }
            Toast.makeText(this, R.string.stats_reset_confirmation, Toast.LENGTH_SHORT).show();
            // Si les stats étaient visibles, on pourrait vouloir les rafraîchir
            if (statisticsVisible && inflatedStatsView != null) {
                updateStatisticsTextViews();
            }
        }
    }

    /**
     * Affiche la boîte de dialogue "À Propos" en utilisant un layout personnalisé,
     * incluant des informations sur l'application et un lien cliquable vers le site web.
     */
    private void showAboutDialog() {
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        LayoutInflater inflater = getLayoutInflater();
        View dialogView = inflater.inflate(R.layout.dialog_about, null); // Gonfle le layout
        builder.setView(dialogView);
        builder.setCancelable(true); // Permet de fermer

        // Récupère les vues du layout
        TextView websiteLinkTextView = dialogView.findViewById(R.id.websiteLinkTextView);
        Button okButton = dialogView.findViewById(R.id.dialogOkButtonAbout);

        final AlertDialog dialog = builder.create();

        // Rend le lien cliquable pour ouvrir le navigateur
        websiteLinkTextView.setOnClickListener(v -> {
            Intent browserIntent = new Intent(Intent.ACTION_VIEW, Uri.parse(getString(R.string.about_website_url)));
            try {
                startActivity(browserIntent);
            } catch (ActivityNotFoundException e) {
                // Gère le cas où aucun navigateur n'est installé
                Toast.makeText(this, "Aucun navigateur web trouvé.", Toast.LENGTH_SHORT).show();
            }
        });

        // Bouton OK pour fermer la dialogue
        okButton.setOnClickListener(v -> dialog.dismiss());

        dialog.show();
    }


    // --- Gestion Stats UI ---

    /**
     * Affiche ou masque le panneau de statistiques.
     * Gonfle le layout via ViewStub si c'est la première fois.
     */
    private void toggleStatistics() {
        statisticsVisible = !statisticsVisible;
        if (statisticsVisible) {
            if (inflatedStatsView == null) { // Gonfle si pas encore fait
                inflatedStatsView = statisticsViewStub.inflate();
                // Attache listener au bouton Back une fois la vue gonflée
                Button backButton = inflatedStatsView.findViewById(R.id.backButton);
                backButton.setOnClickListener(v -> toggleStatistics()); // Recliquer sur Back re-appelle toggle
            }
            updateStatisticsTextViews(); // Remplit les champs avec les données actuelles
            inflatedStatsView.setVisibility(View.VISIBLE); // Affiche
            multiplayerButton.setVisibility(View.GONE); // Masque bouton multi
        } else {
            if (inflatedStatsView != null) { // Masque si la vue existe
                inflatedStatsView.setVisibility(View.GONE);
            }
            multiplayerButton.setVisibility(View.VISIBLE); // Réaffiche bouton multi
        }
    }

    /**
     * Remplit les TextViews du panneau de statistiques avec les données de l'objet GameStats.
     * Doit être appelé seulement après que `inflatedStatsView` a été initialisé.
     */
    private void updateStatisticsTextViews() {
        if (inflatedStatsView == null || gameStats == null) return;

        // Récupération des TextViews dans la vue gonflée
        TextView highScoreStatsLabel = inflatedStatsView.findViewById(R.id.high_score_stats_label);
        TextView totalGamesPlayedLabel = inflatedStatsView.findViewById(R.id.total_games_played_label);
        TextView totalGamesStartedLabel = inflatedStatsView.findViewById(R.id.total_games_started_label);
        TextView winPercentageLabel = inflatedStatsView.findViewById(R.id.win_percentage_label);
        TextView totalPlayTimeLabel = inflatedStatsView.findViewById(R.id.total_play_time_label);
        TextView totalMovesLabel = inflatedStatsView.findViewById(R.id.total_moves_label);
        TextView currentMovesLabel = inflatedStatsView.findViewById(R.id.current_moves_label);
        TextView currentGameTimeLabel = inflatedStatsView.findViewById(R.id.current_game_time_label);
        TextView averageGameTimeLabel = inflatedStatsView.findViewById(R.id.average_game_time_label);
        TextView bestWinningTimeLabel = inflatedStatsView.findViewById(R.id.best_winning_time_label);
        TextView worstWinningTimeLabel = inflatedStatsView.findViewById(R.id.worst_winning_time_label);
        TextView totalMergesLabel = inflatedStatsView.findViewById(R.id.total_merges_label);
        TextView highestTileLabel = inflatedStatsView.findViewById(R.id.highest_tile_label);
        TextView objectiveReachedLabel = inflatedStatsView.findViewById(R.id.number_of_time_objective_reached_label);
        TextView perfectGameLabel = inflatedStatsView.findViewById(R.id.perfect_game_label);
        TextView multiplayerGamesWonLabel = inflatedStatsView.findViewById(R.id.multiplayer_games_won_label);
        TextView multiplayerGamesPlayedLabel = inflatedStatsView.findViewById(R.id.multiplayer_games_played_label);
        TextView multiplayerWinRateLabel = inflatedStatsView.findViewById(R.id.multiplayer_win_rate_label);
        TextView multiplayerBestWinningStreakLabel = inflatedStatsView.findViewById(R.id.multiplayer_best_winning_streak_label);
        TextView multiplayerAverageScoreLabel = inflatedStatsView.findViewById(R.id.multiplayer_average_score_label);
        TextView averageTimePerGameMultiLabel = inflatedStatsView.findViewById(R.id.average_time_per_game_label); // Potentiel ID dupliqué dans layout?
        TextView totalMultiplayerLossesLabel = inflatedStatsView.findViewById(R.id.total_multiplayer_losses_label);
        TextView multiplayerHighScoreLabel = inflatedStatsView.findViewById(R.id.multiplayer_high_score_label);
        TextView mergesThisGameLabel = inflatedStatsView.findViewById(R.id.merges_this_game);

        // MAJ textes avec getters de gameStats
        highScoreStatsLabel.setText(getString(R.string.high_score_stats, gameStats.getOverallHighScore()));
        totalGamesPlayedLabel.setText(getString(R.string.total_games_played, gameStats.getTotalGamesPlayed()));
        totalGamesStartedLabel.setText(getString(R.string.total_games_started, gameStats.getTotalGamesStarted()));
        totalMovesLabel.setText(getString(R.string.total_moves, gameStats.getTotalMoves()));
        currentMovesLabel.setText(getString(R.string.current_moves, gameStats.getCurrentMoves()));
        mergesThisGameLabel.setText(getString(R.string.merges_this_game_label, gameStats.getMergesThisGame()));
        totalMergesLabel.setText(getString(R.string.total_merges, gameStats.getTotalMerges()));
        highestTileLabel.setText(getString(R.string.highest_tile, gameStats.getHighestTile()));
        objectiveReachedLabel.setText(getString(R.string.number_of_time_objective_reached, gameStats.getNumberOfTimesObjectiveReached()));
        perfectGameLabel.setText(getString(R.string.perfect_games, gameStats.getPerfectGames()));
        multiplayerGamesWonLabel.setText(getString(R.string.multiplayer_games_won, gameStats.getMultiplayerGamesWon()));
        multiplayerGamesPlayedLabel.setText(getString(R.string.multiplayer_games_played, gameStats.getMultiplayerGamesPlayed()));
        multiplayerBestWinningStreakLabel.setText(getString(R.string.multiplayer_best_winning_streak, gameStats.getMultiplayerBestWinningStreak()));
        multiplayerAverageScoreLabel.setText(getString(R.string.multiplayer_average_score, gameStats.getMultiplayerAverageScore()));
        totalMultiplayerLossesLabel.setText(getString(R.string.total_multiplayer_losses, gameStats.getTotalMultiplayerLosses()));
        multiplayerHighScoreLabel.setText(getString(R.string.multiplayer_high_score, gameStats.getMultiplayerHighestScore()));

        // Calculs Pourcentages
        String winPercentage = (gameStats.getTotalGamesStarted() > 0) ? String.format("%.2f%%", ((double) gameStats.getNumberOfTimesObjectiveReached() / gameStats.getTotalGamesStarted()) * 100) : "N/A";
        winPercentageLabel.setText(getString(R.string.win_percentage, winPercentage));
        String multiplayerWinRate = (gameStats.getMultiplayerGamesPlayed() > 0) ? String.format("%.2f%%", ((double) gameStats.getMultiplayerGamesWon() / gameStats.getMultiplayerGamesPlayed()) * 100) : "N/A";
        multiplayerWinRateLabel.setText(getString(R.string.multiplayer_win_rate, multiplayerWinRate));

        // Calculs Temps
        totalPlayTimeLabel.setText(getString(R.string.total_play_time, GameStats.formatTime(gameStats.getTotalPlayTimeMs())));
        // Calcule le temps de la partie en cours seulement si elle n'est pas finie
        long currentDurationMs = 0;
        if (game != null && gameStats != null && currentGameState == GameFlowState.PLAYING && gameStats.getCurrentGameStartTimeMs() > 0) {
            currentDurationMs = System.currentTimeMillis() - gameStats.getCurrentGameStartTimeMs();
        }
        currentGameTimeLabel.setText(getString(R.string.current_game_time, GameStats.formatTime(currentDurationMs)));

        averageGameTimeLabel.setText(getString(R.string.average_time_per_game, GameStats.formatTime(gameStats.getAverageGameTimeMs())));
        averageTimePerGameMultiLabel.setText(getString(R.string.average_time_per_game_label, GameStats.formatTime(gameStats.getMultiplayerAverageTimeMs()))); // Assurez-vous que l'ID R.string.average_time_per_game_label est correct
        bestWinningTimeLabel.setText(getString(R.string.best_winning_time, (gameStats.getBestWinningTimeMs() != Long.MAX_VALUE) ? GameStats.formatTime(gameStats.getBestWinningTimeMs()) : "N/A"));
        worstWinningTimeLabel.setText(getString(R.string.worst_winning_time, (gameStats.getWorstWinningTimeMs() != 0) ? GameStats.formatTime(gameStats.getWorstWinningTimeMs()) : "N/A"));
    }


    // --- Placeholders Multi ---

    /** Affiche un dialogue placeholder pour le multijoueur. */
    private void showMultiplayerScreen() {
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        builder.setTitle("Multijoueur").setMessage("Fonctionnalité multijoueur à venir !").setPositiveButton("OK", null);
        builder.create().show();
    }

    // --- Sauvegarde / Chargement ---

    /** Sauvegarde l'état du jeu et le meilleur score via SharedPreferences. */
    private void saveGame() {
        SharedPreferences.Editor editor = preferences.edit();
        if (game != null) {
            editor.putString(GAME_STATE_KEY, game.toString()); // Sérialise Game (plateau + score courant)
            // Le meilleur score est géré et sauvegardé par GameStats, mais on le sauve aussi ici pour la synchro au chargement
            editor.putInt(HIGH_SCORE_KEY, game.getHighestScore());
        } else {
            editor.remove(GAME_STATE_KEY); // Optionnel: nettoyer si pas de jeu
        }
        editor.apply(); // Utilise apply() pour une sauvegarde asynchrone
    }

    /** Charge l'état du jeu depuis SharedPreferences et synchronise le meilleur score. */
    private void loadGame() {
        String gameStateString = preferences.getString(GAME_STATE_KEY, null);
        // Charge le meilleur score depuis les préférences (sera aussi chargé par GameStats mais on l'utilise ici pour Game)
        int savedHighScore = preferences.getInt(HIGH_SCORE_KEY, 0);

        // Assure que GameStats charge son état (y compris le HS global)
        if (gameStats == null) { gameStats = new GameStats(this); } // Précaution
        gameStats.loadStats(); // Charge explicitement les stats (ce qui devrait inclure le HS global)
        // S'assure que le HS chargé par gameStats est cohérent avec celui des prefs directes
        if (savedHighScore > gameStats.getOverallHighScore()) {
            gameStats.setHighestScore(savedHighScore); // Assure que GameStats a au moins le HS trouvé ici
        } else {
            savedHighScore = gameStats.getOverallHighScore(); // Utilise le HS de GameStats s'il est plus grand
        }


        Game loadedGame = null;
        if (gameStateString != null) {
            loadedGame = Game.deserialize(gameStateString);
        }

        if (loadedGame != null) {
            game = loadedGame;
            game.setHighestScore(savedHighScore); // Applique le HS synchronisé
            // Détermine l'état basé sur le jeu chargé
            if (game.isGameOver()) {
                currentGameState = GameFlowState.GAME_OVER;
            } else if (game.isGameWon()) {
                // Si on charge une partie déjà gagnée, on considère qu'on a déjà vu la dialog
                currentGameState = GameFlowState.WON_DIALOG_SHOWN;
            } else {
                currentGameState = GameFlowState.PLAYING;
                // Le timer sera (re)démarré dans onResume si l'état est PLAYING
            }
        } else {
            // Pas de sauvegarde valide ou erreur de désérialisation -> Commence une nouvelle partie implicitement
            game = null; // Sera géré par l'appel à startNewGame dans initializeGameAndStats
        }
    }

} // Fin MainActivity